Index: c/src/lib/libbsp/arm/edb7312/ChangeLog
===================================================================
--- c/src/lib/libbsp/arm/edb7312/ChangeLog	(revision e0c13fa383ed34172d1f73b215e44da3f57e1908)
+++ c/src/lib/libbsp/arm/edb7312/ChangeLog	(revision 89866d84f867a75608411843515161aced27df13)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/arm/gba/ChangeLog
===================================================================
--- c/src/lib/libbsp/arm/gba/ChangeLog	(revision e0c13fa383ed34172d1f73b215e44da3f57e1908)
+++ c/src/lib/libbsp/arm/gba/ChangeLog	(revision 89866d84f867a75608411843515161aced27df13)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c: Eliminate empty function from every benchmark timer
+	driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/arm/edb7312/timer/timer.c
===================================================================
--- c/src/lib/libbsp/arm/edb7312/timer/timer.c	(revision e0c13fa383ed34172d1f73b215e44da3f57e1908)
+++ c/src/lib/libbsp/arm/edb7312/timer/timer.c	(revision 89866d84f867a75608411843515161aced27df13)
@@ -12,6 +12,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined
@@ -26,7 +26,7 @@
 
 uint16_t         tstart;
-bool benchmark_timerfind_average_overhead;
+bool benchmark_timer_find_average_overhead;
 
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     *EP7312_SYSCON1 |= EP7312_SYSCON1_TC2_512KHZ;
@@ -35,5 +35,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -49,5 +49,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint16_t         t;
@@ -63,5 +63,5 @@
   total = (uint32_t)0x0000ffff - t;  /* result is 1/512000 = ~2 uS */
   total = (total * 1953) / 1000;   /* convert to uS */
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in XXX microsecond units */
   else {
@@ -75,18 +75,8 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   bool find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -12,6 +12,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined
@@ -35,5 +35,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libbsp/arm/gba/timer/timer.c
===================================================================
--- c/src/lib/libbsp/arm/gba/timer/timer.c	(revision e0c13fa383ed34172d1f73b215e44da3f57e1908)
+++ c/src/lib/libbsp/arm/gba/timer/timer.c	(revision 89866d84f867a75608411843515161aced27df13)
@@ -19,6 +19,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined
@@ -56,13 +56,13 @@
 #endif
 
-bool benchmark_timerfind_average_overhead;
+bool benchmark_timer_find_average_overhead;
 
 /**
- *  @brief benchmark_timerinitialize start TM0 and TM1
+ *  @brief benchmark_timer_initialize start TM0 and TM1
  *
  *  @param  None
  *  @return None
  */
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
   GBA_REG_TM1CNT =  0x0000;                /* Stop Counters         */
@@ -76,5 +76,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -89,5 +89,5 @@
 
 /**
  *  @brief benchmark_timerread return timer countervalue in microseconds.
  *
  *  Used in Timing Test Suite.
@@ -96,5 +96,5 @@
  *  @return Timer value in microseconds
  */
-uint32_t benchmark_timerread( void )
+uint32_t benchmark_timer_read( void )
 {
   uint32_t  ticks;
@@ -111,5 +111,5 @@
   /* convert to uS */
   total = ((ticks * __TickTime_ns) / 1000);
-  if ( benchmark_timerfind_average_overhead == 1 ) {
+  if ( benchmark_timer_find_average_overhead == 1 ) {
       return total;          /* in microseconds */
   }
@@ -123,19 +123,5 @@
 
 /**
- *  @brief Empty function
- *
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- *
- *  @param  None
- *  @return RTEMS_SUCCESSFUL
-*/
-rtems_status_code benchmark_timerempty_function( void )
-{
-   return RTEMS_SUCCESSFUL;
-}
-
-/**
- *  @brief Set benchmark_timerfind_average_overhead flag.
+ *  @brief Set benchmark_timer_find_average_overhead flag.
  *
  *  Used in Timing Test Suite.
@@ -144,6 +130,6 @@
  *  @return None
 */
-void benchmark_timerdisable_subtracting_average_overhead(bool find_flag)
+void benchmark_timer_disable_subtracting_average_overhead(bool find_flag)
 {
-   benchmark_timerfind_average_overhead = find_flag;
+   benchmark_timer_find_average_overhead = find_flag;
 }
@@ -19,6 +19,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined
@@ -76,5 +76,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -89,5 +89,5 @@
 
 /**
- *  @brief benchmark_timerread return timer countervalue in microseconds.
+ *  @brief benchmark_timer_read return timer countervalue in microseconds.
  *
  *  Used in Timing Test Suite.
